@@ -63,6 +63,45 @@
 #   New RC default_otf_view_format
 #   No conversion necessary.
 
+# Incremented to format 15, by prannoy
+#   Add fullscreen_statusbar
+#   No conversion necessary.
+
+# Incremented to format 16, by lasgouttes
+#  Remove force_paint_single_char rc.
+
+# Incremented to format 17, by lasgouttes
+#  Remove rtl_support rc.
+
+# Incremented to format 18, by ef
+#   Add option to allow saving the document directory
+#   No conversion necessary.
+
+# Incremented to format 19, by rgh
+#   remove print support
+
+# Incremented to format 20, by tommaso
+#   Add options to forbid/ignore 'needauth' option
+#   No conversion necessary.
+
+# Incremented to format 21, by spitz
+#   Add jbibtex_alternatives, allow "automatic" value
+#   of bibtex_command and jbibtex_command (actually the
+#   default now)
+#   No conversion necessary.
+
+# Incremented to format 22, by ef
+#   Add pygmentize_command for the python pygments syntax highlighter
+#   No conversion necessary.
+
+# Incremented to format 23, by spitz
+#   Add default_platex_view_format, a default output format for
+#   Japanese documents via pLaTeX.
+#   No conversion necessary.
+
+# Incremented to format 24, by spitz
+#   Rename collapsable to collapsible
+
 # NOTE: The format should also be updated in LYXRC.cpp and
 # in configure.py.
 
@@ -112,10 +151,10 @@ no_match = (False, [])
 
 def remove_obsolete(line):
 	tags = ("\\use_tempdir", "\\spell_command", "\\personal_dictionary",
-				"\\plaintext_roff_command", "\\use_alt_language", 
-				"\\use_escape_chars", "\\use_input_encoding",
-				"\\use_personal_dictionary", "\\use_pspell",
-				"\\use_spell_lib")
+		"\\plaintext_roff_command", "\\use_alt_language",
+		"\\use_escape_chars", "\\use_input_encoding",
+		"\\use_personal_dictionary", "\\use_pspell",
+		"\\use_spell_lib")
 	line = line.lower().lstrip()
 	for tag in tags:
 		if line.lower().startswith(tag):
@@ -306,6 +345,46 @@ def mac_cursor_movement(line):
 ####################################
 
 
+#################################
+# Conversions from LyX 2.1 to 2.2
+
+def remove_force_paint_single_char(line):
+	if not line.lower().startswith("\\force_paint_single_char"):
+		return no_match
+	return (True, "")
+
+def remove_rtl(line):
+	if not line.lower().startswith("\\rtl "):
+		return no_match
+	return (True, "")
+
+def remove_print_support(line):
+	tags = ("\\printer", "\\print_adapt_output", "\\print_command",
+		"\\print_evenpage_flag", "\\print_oddpage_flag", "\\print_pagerange_flag",
+		"\\print_copies_flag", "\\print_collcopies_flag", "\\print_reverse_flag",
+		"\\print_to_printer", "\\print_to_file", "\\print_file_extension")
+	line = line.lower().lstrip()
+	for tag in tags:
+		if line.lower().startswith(tag):
+			return (True, "")
+	return no_match
+
+# End conversions for LyX 2.1 to 2.2
+####################################
+
+#################################
+# Conversions from LyX 2.2 to 2.3
+
+def rename_collapsible(line):
+	return simple_renaming(line, "\\set_color \"collapsable", "\\set_color \"collapsible")
+
+# End conversions for LyX 2.2 to 2.3
+####################################
+
+
+############################################################
+# Format-conversion map. Also add empty format changes here.
+
 conversions = [
 	[  1, [ # there were several conversions for format 1
 		export_menu,
@@ -327,5 +406,14 @@ conversions = [
 	[ 12, []],
 	[ 13, [mac_cursor_movement]],
 	[ 14, []],
-	[ 15, []]
+	[ 15, []],
+	[ 16, [remove_force_paint_single_char]],
+	[ 17, [remove_rtl]],
+	[ 18, []],
+	[ 19, [remove_print_support]],
+	[ 20, []],
+	[ 21, []],
+	[ 22, []],
+	[ 23, []],
+	[ 24, [rename_collapsible]]
 ]
